sequencetools.split_sequence_cyclically_by_weights_with_overhang
================================================================

.. autofunction:: abjad.tools.sequencetools.split_sequence_cyclically_by_weights_with_overhang.split_sequence_cyclically_by_weights_with_overhang
